# Qiskit Code Assistant Jupyterlab Extension

[![Github Actions Status](https://github.com/Qiskit/qiskit-code-assistant-jupyterlab/workflows/Build/badge.svg)](https://github.com/Qiskit/qiskit-code-assistant-jupyterlab/actions/workflows/build.yml)

A JupyterLab extension for Qiskit Code Assistant

You can also use the [VSCode extension](https://github.com/Qiskit/qiskit-code-assistant-vscode)
if you dont have access to Jupyterlab

This extension is composed of a Python package named `qiskit_code_assistant_jupyterlab`
for the server extension and a NPM package named `qiskit-code-assistant-jupyterlab`
for the frontend extension.

## Requirements

- JupyterLab >= 4.2.0
- An IBM Quantum premium account

## Install

To install the extension, execute:

```bash
pip install qiskit_code_assistant_jupyterlab
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall qiskit_code_assistant_jupyterlab
```

## Using the Qiskit Code Assistant

For help setting up and using the Qiskit Code Assistant read [GETTING_STARTED](GETTING_STARTED.md).

## Contributing

To learn more about contributing or installing locally read [CONTRIBUTING](CONTRIBUTING.md).

## Qiskit Code Assistant Terms of use

- Terms of use: [https://quantum.ibm.com/terms](https://quantum.ibm.com/terms)
- Privacy policy: [https://quantum.ibm.com/terms/privacy](https://quantum.ibm.com/terms/privacy)
- Cloud Services Agreement [https://www.ibm.com/support/customer/csol/terms/?id=Z126-6304&cc=us&lc=en](https://www.ibm.com/support/customer/csol/terms/?id=Z126-6304&cc=us&lc=en)
- IBM Cloud Service Description [https://www.ibm.com/support/customer/csol/terms/?id=i126-6605&lc=en](https://www.ibm.com/support/customer/csol/terms/?id=i126-6605&lc=en)
- [End User License Agreement (EULA)](docs/EULA.md) acceptance required before starting to use the model acceptance required before starting to use the model
